scipy.odr.Model
===============

.. currentmodule:: scipy.odr

.. autoclass:: Model

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Model.set_meta



   

